﻿using System;
using System.Collections;
using System.Windows;

using DevExpress.Xpf.Grid;

namespace TestProject
{
    /// <summary>
    /// 메인 윈도우
    /// </summary>
    public partial class MainWindow : Window
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainWindow()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainWindow()
        {
            InitializeComponent();

            this.gridControl.ItemsSource = new nwindDataSetTableAdapters.ProductsTableAdapter().GetData();
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private
        //////////////////////////////////////////////////////////////////////////////// Event

        #region 그리드 컨트롤 커스텀 컬럼 디스플레이 텍스트 처리하기 - gridControl_CustomColumnDisplayText(sender, e)

        /// <summary>
        /// 그리드 컨트롤 커스텀 컬럼 디스플레이 텍스트 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void gridControl_CustomColumnDisplayText(object sender, CustomColumnDisplayTextEventArgs e)
        {
            if(e.Column == null)
            {
                return;
            }

            if(e.Column.FieldName == "UnitPrice")
            {
                string interval = GetInterval(this.gridControl.GetGroupRowValue(e.RowHandle));

                e.DisplayText = interval;
            }
        }

        #endregion
        #region 그리드 컨트롤 커스텀 컬럼 그룹 처리하기 - gridControl_CustomColumnGroup(sender, e)

        /// <summary>
        /// 그리드 컨트롤 커스텀 컬럼 그룹 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void gridControl_CustomColumnGroup(object sender, CustomColumnSortEventArgs e)
        {
            if(e.Column != null & e.Column.FieldName == "UnitPrice")
            {
                double x = Math.Floor(Convert.ToDouble(e.Value1) / 10);
                double y = Math.Floor(Convert.ToDouble(e.Value2) / 10);

                int result = Comparer.Default.Compare(x, y);

                if(x > 9 && y > 9)
                {
                    result = 0;
                }

                e.Result = result;

                e.Handled = true;
            }
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////// Function

        #region 간격 구하기 - GetInterval(value)

        /// <summary>
        /// 간격 구하기
        /// </summary>
        /// <param name="value">값</param>
        /// <returns>간격</returns>
        private static string GetInterval(object value)
        {
            double doubleValue = Math.Floor(Convert.ToDouble(value) / 10);

            string result;

            if(doubleValue > 9)
            {
                result = string.Format(">= {0:c} ", 100);
            }
            else
            {
                result = string.Format("{0:c} - {1:c}", doubleValue * 10, (doubleValue + 1) * 10);
            }

            return result;
        }

        #endregion
    }
}